@@ -109,9 +109,10 @@ class ZugferdMixin:
         doc.trade.agreement.seller.address.city_name = remove_control_characters(
             invoice.invoice_from_city
         )
-        doc.trade.agreement.seller.address.country_id = str(
-            remove_control_characters(invoice.invoice_from_country)
-        )
+        if str(invoice.invoice_from_country)[0] != 'X':
+            doc.trade.agreement.seller.address.country_id = str(
+                remove_control_characters(invoice.invoice_from_country)
+            )
 
         if invoice.invoice_from_tax_id:
             doc.trade.agreement.seller.tax_registrations.add(
@@ -154,9 +155,10 @@ class ZugferdMixin:
         doc.trade.agreement.buyer.address.city_name = remove_control_characters(
             invoice.invoice_to_city
         )
-        doc.trade.agreement.buyer.address.country_id = remove_control_characters(
-            str(invoice.invoice_to_country)
-        )
+        if str(invoice.invoice_to_country)[0] != 'X':
+            doc.trade.agreement.buyer.address.country_id = remove_control_characters(
+                str(invoice.invoice_to_country)
+            )
 
         if invoice.invoice_to_vat_id:
             doc.trade.agreement.buyer.tax_registrations.add(
@@ -165,6 +167,11 @@ class ZugferdMixin:
                 )
             )
 
+        if invoice.event.settings.get("zugferd_include_delivery_date", as_type=bool):
+            ds = [l.event_date_to or l.event_date_from for l in invoice.lines.all() if l.event_date_to or l.event_date_from]
+            if ds:
+                doc.trade.delivery.event.occurrence = max(ds)
+
         note = IncludedNote()
         note.content.add(_("Order code: {code}").format(code=invoice.order.full_code))
         doc.header.notes.add(note)
@@ -281,6 +288,10 @@ class ZugferdMixin:
         if not invoice.invoice_from_name or not invoice.invoice_to_country or not invoice.invoice_from_country:
             return fname, ftype, content
 
+        if str(invoice.invoice_to_country) in settings.COUNTRIES_OVERRIDE:
+            # It's not possible to generate a valid ZUGFeRD invoice with the recipient in a non-standard country code (e.g. Kosovo)
+            return fname, ftype, content
+
         try:
             xml = self._zugferd_generate_document(invoice).serialize(schema="FACTUR-X_" + self.schema)
         except Exception as e:
